@@ -5,14 +5,14 @@ get.l <- function(theta,K,y) {
 tpm  <- getTpm(theta,K,stationary=TRUE)
 ispd <- revise.ispd(tpm)
 rrr  <- attr(y,"lvls")
-Rho  <- cnvrtRho(getRho(theta,K,rhovals=rrr,stationary=TRUE,
-                 prednames="Intercept"))
+Rho  <- getRho(theta,K,rhovals=rrr,stationary=TRUE,
+               prednames="Intercept")
 
 # Run through the list "y":
 ndat <- length(y)
 xll  <- numeric(ndat)
 ky   <- 0
-fy   <- ffun(y,Rho,type=2)
+fy   <- ffun(y,Rho,type=1)
 j2   <- 0
 for(yl in y) {
     ylv <- yl[,1]
