@@ -2,7 +2,7 @@ update.hmm.discnp <- function(object,...,data,Kplus1=FALSE,tpm2=NULL,
                               verbose=FALSE,method=NULL,optimiser=NULL,
                               stationary=NULL,mixture=NULL,cis=NULL,
                               tolerance=NULL,itmax=NULL,crit=NULL,
-                              newstyle=NULL,X=NULL,addIntercept=NULL) {
+                              X=NULL,addIntercept=NULL) {
 
 # Check that the "data" argument is compatible with the "object"
 # argument.
@@ -18,7 +18,6 @@ if(is.null(cis))          cis          <- object$args$cis
 if(is.null(tolerance))    tolerance    <- object$args$tolerance
 if(is.null(itmax))        itmax        <- object$args$itmax
 if(is.null(crit))         crit         <- object$args$crit
-if(is.null(newstyle))     newstyle     <- object$args$newstyle
 if(is.null(addIntercept)) addIntercept <- object$args$addIntercept
 
 # Increment the number of states by one if required.
@@ -60,7 +59,7 @@ if(Kplus1) {
 }
 
 # Deal with the predictor variables if these are supplied.
-if(object$args$newstyle && ncol(Rho) > 3) {
+if(ncol(Rho) > 3) {
 # X used previously:
     if(is.null(X)) stop("Argument \"X\" must be specified.\n")
     X <- tidyList(X,rp="predictor",addIntercept=addIntercept)
@@ -99,7 +98,7 @@ if(identical(par0$tpm,NA)) {
 fit <- hmm(y=data,K=K,par0=par0,method=method,optimiser=optimiser,
            stationary=stationary,mixture=mixture,cis=cis,
            tolerance=tolerance,itmax=itmax,crit=crit,
-           newstyle=newstyle,X=X,addIntercept=addIntercept,
+           X=X,addIntercept=addIntercept,
            verbose=verbose,...)
 nafter <- which(names(fit)=="log.like") - 1
 fit <- append(fit,list(init.log.like=ill),after=nafter)
