@@ -1,9 +1,18 @@
-viterbi <- function(y,model=NULL,tpm,Rho,ispd=NULL,log=FALSE,warn=TRUE) {
+viterbi <- function(y,model=NULL,tpm=NULL,Rho=NULL,ispd=NULL,
+                    log=FALSE,warn=TRUE) {
 #
 # Function viterbi to apply the Viterbi algorithm to a collection
 # of data sequences, given the parameters of the model.
 #
 
+if(inherits(y,"multipleHmmDataSets")) {
+    rslt <- lapply(y,function(x,model,tpm,Rho,ispd,log,warn){
+                         viterbi(x,model,tpm,Rho,ispd,log,warn)},
+                         model=model,tpm=tpm,Rho=Rho,ispd=ispd,
+                         log=log,warn=warn)
+    return(rslt)
+}
+
 # If ``model'' is present, get the parameters from that, and
 # ignore those (if any) specified as separate arguments.
 if(!is.null(model)) {
@@ -11,19 +20,25 @@ if(!is.null(model)) {
 	Rho  <- model$Rho
 	ispd <- model$ispd
 }
+if(is.null(tpm) | is.null(Rho))
+    stop("At least one of \"tpm\" and \"Rho\" was not supplied.\n")
 
-# If Rho is presented in the "logistic style" parameterisation,
-# convert it to a matrix of probabilities.
-if(class(Rho)=="data.frame") Rho <- cnvrtRho(Rho)
+# Convert Rho if necessary.
+if(inherits(Rho,"matrix")) Rho <- cnvrtRho(Rho)
 
 # Set the type:
-# 1 <--> univariate, new (logistic) style # Won't happen --- see above!
-# 2 <--> univariate, old (matrix) style
-# 3 <--> bivariate, independent
-# 4 <--> bivariate, dependent
-type <- switch(class(Rho),data.frame=1,matrix=2,list=3,array=4,NULL)
-if(is.null(type)) stop("Argument \"Rho\" is not of an appropriate form.\n")
-
+# 1 <--> univariate
+# 2 <--> bivariate, independent
+# 3 <--> bivariate, dependent
+if(inherits(Rho,"data.frame")) {
+    type <- 1
+} else if(inherits(Rho,"list")) {
+    type <- 2
+} else if(inherits(Rho,"array")) {
+    type <- 3
+} else {
+    stop("Object \"Rho\" has an incorrect class.\n")
+}
 K <- nrow(tpm)
 if(missing(y)) {
 	y <- if(!is.null(model)) model[["y"]] else NULL
@@ -35,6 +50,7 @@ if(missing(y)) {
 y    <- tidyList(y)
 nseq <- length(y)
 lns  <- sapply(y,length)
+lvls <- attr(y,"lvls")
 
 # Build ispd if it was given as NULL
 if(is.null(ispd)) ispd <- revise.ispd(tpm)
@@ -42,18 +58,32 @@ if(is.null(ispd)) ispd <- revise.ispd(tpm)
 # Make sure that the y-values are compatible with Rho.
 Rho <- check.yval(attr(y,"lvls"),Rho,type,warn=warn)
 
-fys <- function(y,s,Rho,type) {
-    switch(type,NA,Rho[y,s],Rho[[1]][y[1],s]*Rho[[2]][y[2],s],
-                Rho[cbind(y[1],y[2],s)])
+fys <- function(y,Rho,type,lvls) {
+   Dat <- switch(EXPR=type,
+               list(data.frame(y=factor(y,levels=lvls),Intercept=1)),
+               list(data.frame(y1=factor(y[1],levels=lvls[[1]]),
+                               y2=factor(y[2],levels=lvls[[2]]),
+                               Intercept=1)),
+               list(data.frame(y1=factor(y[1],levels=lvls[[1]]),
+                               y2=factor(y[2],levels=lvls[[2]]),
+                               Intercept=1)))
+   as.vector(ffun(Dat,Rho,type))
 }
 
-sK <- switch(type,NA,colnames(Rho),colnames(Rho[[1]]),dimnames(Rho)[[3]])
-if(is.null(sK)) sK <- 1:K
-rslt <- list()
+# Set the names of the states.
+stnms <- switch(type,
+             levels(Rho$state),
+             colnames(Rho[[1]]),
+             dimnames(Rho)[[3]]
+         )
+if(is.null(stnms)) stnms <- as.character(1:nrow(tpm))
+
+# Rubber hits road.
+rslt <- vector("list",nseq)
 for(j in 1:nseq) {
 	psi <- vector("list",nseq)
         yt  <- y[[j]][1,]
-        rrr <- fys(yt,sK,Rho,type)
+        rrr <- fys(yt,Rho,type,lvls)
         if(log) {
             delta <- log(ispd) + log(rrr)
         } else {
@@ -75,7 +105,7 @@ for(j in 1:nseq) {
 		                 # vectors, each of length between
                                  # 1 and K = the number of states.
                 yt  <- y[[j]][tt,]
-                rrr <- fys(yt,sK,Rho,type)
+                rrr <- fys(yt,Rho,type,lvls)
 		if(log) {
                     delta <- log(rrr) + apply(delta + log(tpm),2,max)
                 } else {
@@ -83,7 +113,7 @@ for(j in 1:nseq) {
                     delta <- delta/sum(delta)
                 }
 	}
-	temp <- list()
+	temp <- vector("list",nj)
 	temp[[nj]] <- (1:K)[delta==max(delta)]
 	for(tt in (nj-1):1) {
 		i <- 0
@@ -96,8 +126,9 @@ for(j in 1:nseq) {
 			}
 		}
 	}
-        rrr <- matrix(unlist(temp[[1]]), nrow = nj)
-        rslt[[j]] <- if(ncol(rrr)==1) as.vector(rrr) else rrr
+        sss <- stnms[unlist(temp[[1]])]
+        sss <- matrix(sss, nrow = nj)
+        rslt[[j]] <- if(ncol(sss)==1) as.vector(sss) else sss
 }
 if(nseq==1) rslt[[1]] else rslt
 }
